polyc-a2a 2026.10.0

polychrome A2A edge: serves a domain-signed Agent Card and drives message/send tasks onto a turn.
docs.rs failed to build polyc-a2a-2026.10.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.